@@ -36,6 +36,7 @@ from flet.dropdown import Option
 from robot.api.deco import keyword, library
 from robot.errors import RobotError
 from robot.libraries.BuiltIn import BuiltIn, RobotNotRunningError
+from robot.utils.dotdict import DotDict
 
 from RPA.Assistant.flet_client import FletClient
 from RPA.Assistant.types import Icon, Options, Result, Size, Location
@@ -989,11 +990,17 @@ class Assistant:
         self._client.display_flet_window(
             title, height, width, on_top, location, timeout
         )
-        results = self._client.results
+        results = self._get_results()
+
         if clear:
             self.clear_dialog()
+
         return results
 
+    def _get_results(self) -> DotDict:
+        results = self._client.results
+        return DotDict(**results)
+
     @keyword(tags=["dialog"])
     def ask_user(self, timeout: int = 180, **options: Any) -> Result:
         """Same as ``Run Dialog`` it will create a dialog from all the defined
@@ -1204,10 +1211,11 @@ class Assistant:
 
         """
         if default:
-            try:
+            default = float(default)
+
+            # Is this even necessary?
+            if default.is_integer():
                 default = int(default)
-            except ValueError:
-                default = float(default)
 
             if slider_min > default or slider_max < default:
                 raise ValueError(f"Slider {name} had an out of bounds default value.")
